package org.neuroph.contrib.tileclassification.gui;

import java.util.List;

import javax.swing.SwingWorker;

import org.neuroph.core.NeuralNetwork;
import org.neuroph.core.learning.LearningRule;
import org.neuroph.core.learning.SupervisedLearning;

public class TrainerSwingWorker extends SwingWorker<Void, Double>
{
	private TileClassificationTrainerGui gui;

	public TrainerSwingWorker(TileClassificationTrainerGui gui)
	{
		this.gui = gui;
	}
	
	@Override
	protected Void doInBackground() throws Exception
	{
		NeuralNetwork activeNeuralNetwork = gui.getActiveNeuralNetwork();
		
		if(activeNeuralNetwork != null ) {
			LearningRule learningRule = activeNeuralNetwork.getLearningRule();
			if(learningRule != null && learningRule instanceof SupervisedLearning) {
				SupervisedLearning supervisedLearningRule = (SupervisedLearning) learningRule;
				double learningRate = gui.getLearningRate();
				supervisedLearningRule.setLearningRate(learningRate);
				while(!isCancelled()) {
					supervisedLearningRule.doLearningEpoch(learningRule.getTrainingSet());
					publish(supervisedLearningRule.getTotalNetworkError());
				}
			}
		}
		
		return null;
	}
	
	@Override
	protected void process(List<Double> chunks)
	{
		if(chunks != null && chunks.size() > 0) {
			Double netError = chunks.get(chunks.size() - 1);
			gui.setNetError(netError);
		}
	}

}
